@@ -20,19 +20,22 @@
  *
  */
 
+#include "app/logging.h"
 #include "cliplugin.h"
-#include "kerfuffle/cliinterface.h"
+//#include "kerfuffle/cliinterface.h"
 #include "kerfuffle/kerfuffle_export.h"
 
-#include <KDebug>
-
 #include <QDateTime>
+#include <QDebug>
 #include <QDir>
 #include <QString>
 #include <QStringList>
+#include <KPluginFactory>
+
+Q_LOGGING_CATEGORY(KERFUFFLE_PLUGIN, "ark.kerfuffle.clirar", QtWarningMsg)
 
 using namespace Kerfuffle;
-
+K_PLUGIN_FACTORY( CliPluginFactory, registerPlugin< CliPlugin >(); )
 CliPlugin::CliPlugin(QObject *parent, const QVariantList& args)
         : CliInterface(parent, args)
         , m_parseState(ParseStateColumnDescription1)
@@ -42,6 +45,7 @@ CliPlugin::CliPlugin(QObject *parent, const QVariantList& args)
         , m_isUnrarFree(false)
         , m_isUnrarVersion5(false)
 {
+    qCDebug(KERFUFFLE_PLUGIN) << "Loaded cli_rar plugin";
 }
 
 CliPlugin::~CliPlugin()
@@ -69,7 +73,7 @@ ParameterList CliPlugin::parameterList() const
         p[ListProgram] = p[ExtractProgram] = QStringList() << QLatin1String( "unrar" );
         p[DeleteProgram] = p[AddProgram] = QStringList() << QLatin1String( "rar" );
 
-        p[ListArgs] = QStringList() << QLatin1String( "vt" ) << QLatin1String( "-c-" ) << QLatin1String( "-v" ) << QLatin1String( "$Archive" );
+        p[ListArgs] = QStringList() << QLatin1String( "vt" ) << QLatin1String( "-c-" ) << QLatin1String( "-v" ) << QLatin1String("$PasswordSwitch") << QLatin1String( "$Archive" );
         p[ExtractArgs] = QStringList() << QLatin1String( "-kb" ) << QLatin1String( "-p-" )
                                        << QLatin1String( "$PreservePathSwitch" )
                                        << QLatin1String( "$PasswordSwitch" )
@@ -79,6 +83,7 @@ ParameterList CliPlugin::parameterList() const
         p[PreservePathSwitch] = QStringList() << QLatin1String( "x" ) << QLatin1String( "e" );
         p[RootNodeSwitch] = QStringList() << QLatin1String( "-ap$Path" );
         p[PasswordSwitch] = QStringList() << QLatin1String( "-p$Password" );
+        p[PasswordHeaderSwitch] = QStringList() << QLatin1String("-hp$Password");
 
         p[DeleteArgs] = QStringList() << QLatin1String( "d" ) << QLatin1String( "$Archive" ) << QLatin1String( "$Files" );
 
@@ -91,7 +96,7 @@ ParameterList CliPlugin::parameterList() const
                              << QLatin1String( "Q" ) //cancel
                              ;
 
-        p[AddArgs] = QStringList() << QLatin1String( "a" ) << QLatin1String( "$Archive" ) << QLatin1String( "$Files" );
+        p[AddArgs] = QStringList() << QLatin1String( "a" ) << QLatin1String( "$Archive" ) << QLatin1String("$PasswordSwitch") << QLatin1String( "$Files" );
 
         p[PasswordPromptPattern] = QLatin1String("Enter password \\(will not be echoed\\) for");
 
@@ -152,7 +157,6 @@ bool CliPlugin::readListLine(const QString &line)
             e[Permissions] = m_entryDetails.value(QLatin1String("attributes"));
             e[CRC] = m_entryDetails.value(QLatin1String("crc32"));
             e[IsPasswordProtected] = m_isPasswordProtected;
-            kDebug() << "Added entry: " << e;
 
             emit entry(e);
 
@@ -243,9 +247,9 @@ bool CliPlugin::readListLine(const QString &line)
                 m_remainingIgnoredSubHeaderLines = 3;
             }
 
-            kDebug() << "Found a subheader of type" << subHeaderType;
-            kDebug() << "The next" << m_remainingIgnoredSubHeaderLines
-                     << "lines will be ignored";
+            qCDebug(KERFUFFLE_PLUGIN) << "Found a subheader of type" << subHeaderType;
+            qCDebug(KERFUFFLE_PLUGIN) << "The next" << m_remainingIgnoredSubHeaderLines
+                                      << "lines will be ignored";
 
             return true;
         } else if (line.startsWith(headerString)) {
@@ -328,7 +332,6 @@ bool CliPlugin::readListLine(const QString &line)
         e[Method] = details.at(7);
         e[Version] = details.at(8);
         e[IsPasswordProtected] = m_isPasswordProtected;
-        kDebug() << "Added entry: " << e;
 
         // #314297: When RAR 3.x and RAR 4.x list a symlink, they output an
         //          extra line after the "Host OS/Solid/Old" one mentioning the
@@ -357,6 +360,4 @@ bool CliPlugin::readListLine(const QString &line)
     return true;
 }
 
-KERFUFFLE_EXPORT_PLUGIN(CliPlugin)
-
 #include "cliplugin.moc"
