@@ -24,10 +24,14 @@
  */
 
 #include "gzplugin.h"
-#include "kerfuffle/kerfuffle_export.h"
+#include "kerfuffle_export.h"
 
 #include <QString>
 
+#include <KPluginFactory>
+
+K_PLUGIN_FACTORY( GzipPluginFactory, registerPlugin< LibGzipInterface >(); )
+
 LibGzipInterface::LibGzipInterface(QObject *parent, const QVariantList & args)
         : LibSingleFileInterface(parent, args)
 {
@@ -39,6 +43,4 @@ LibGzipInterface::~LibGzipInterface()
 {
 }
 
-KERFUFFLE_EXPORT_PLUGIN(LibGzipInterface)
-
 #include "gzplugin.moc"
