@@ -23,22 +23,26 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
+#include "app/logging.h"
 #include "singlefileplugin.h"
 #include "kerfuffle/kerfuffle_export.h"
 #include "kerfuffle/queries.h"
 
 #include <QByteArray>
+#include <QDebug>
 #include <QFile>
 #include <QFileInfo>
 #include <QString>
 
-#include <KDebug>
 #include <KFilterDev>
-#include <KLocale>
+#include <KLocalizedString>
+
+Q_LOGGING_CATEGORY(KERFUFFLE_PLUGIN, "ark.kerfuffle.singlefile", QtWarningMsg)
 
 LibSingleFileInterface::LibSingleFileInterface(QObject *parent, const QVariantList & args)
         : Kerfuffle::ReadOnlyArchiveInterface(parent, args)
 {
+    qCDebug(KERFUFFLE_PLUGIN) << "Loaded singlefile plugin";
 }
 
 LibSingleFileInterface::~LibSingleFileInterface()
@@ -61,20 +65,20 @@ bool LibSingleFileInterface::copyFiles(const QList<QVariant> & files, const QStr
         return true;
     }
 
-    kDebug() << "Extracting to" << outputFileName;
+    qCDebug(KERFUFFLE_PLUGIN) << "Extracting to" << outputFileName;
 
     QFile outputFile(outputFileName);
     if (!outputFile.open(QIODevice::WriteOnly)) {
-        kDebug() << "Failed to open output file" << outputFile.errorString();
-        emit error(i18nc("@info", "Ark could not extract <filename>%1</filename>.", outputFile.fileName()));
+        qCCritical(KERFUFFLE_PLUGIN) << "Failed to open output file" << outputFile.errorString();
+        emit error(xi18nc("@info", "Ark could not extract <filename>%1</filename>.", outputFile.fileName()));
 
         return false;
     }
 
-    QIODevice *device = KFilterDev::deviceForFile(filename(), m_mimeType, false);
+    KCompressionDevice *device = new KCompressionDevice(filename(), KFilterDev::compressionTypeForMimeType(m_mimeType));
     if (!device) {
-        kDebug() << "Could not create KFilterDev";
-        emit error(i18nc("@info", "Ark could not open <filename>%1</filename> for extraction.", filename()));
+        qCCritical(KERFUFFLE_PLUGIN) << "Could not create KCompressionDevice";
+        emit error(xi18nc("@info", "Ark could not open <filename>%1</filename> for extraction.", filename()));
 
         return false;
     }
@@ -88,7 +92,7 @@ bool LibSingleFileInterface::copyFiles(const QList<QVariant> & files, const QStr
         bytesRead = device->read(dataChunk.data(), dataChunk.size());
 
         if (bytesRead == -1) {
-            emit error(i18nc("@info", "There was an error while reading <filename>%1</filename> during extraction.", filename()));
+            emit error(xi18nc("@info", "There was an error while reading <filename>%1</filename> during extraction.", filename()));
             break;
         } else if (bytesRead == 0) {
             break;
@@ -104,7 +108,7 @@ bool LibSingleFileInterface::copyFiles(const QList<QVariant> & files, const QStr
 
 bool LibSingleFileInterface::list()
 {
-    kDebug();
+    qCDebug(KERFUFFLE_PLUGIN) << "Listing archive contents";
 
     const QString filename = uncompressedFileName();
 
@@ -146,7 +150,7 @@ const QString LibSingleFileInterface::uncompressedFileName() const
     QString uncompressedName(QFileInfo(filename()).fileName());
 
     foreach(const QString & extension, m_possibleExtensions) {
-        kDebug() << extension;
+        qCDebug(KERFUFFLE_PLUGIN) << extension;
 
         if (uncompressedName.endsWith(extension, Qt::CaseInsensitive)) {
             uncompressedName.chop(extension.size());
@@ -157,4 +161,3 @@ const QString LibSingleFileInterface::uncompressedFileName() const
     return uncompressedName + QLatin1String( ".uncompressed" );
 }
 
-#include "singlefileplugin.moc"
